import pickle as pkl


def query(collection_path):
    """Reads the collection and print the documents ranked by relevance with
    respect to the query

    Args:
        collection_path: Path of the collection file

    """
    collection = pkl.load(open(collection_path, "rb"))
    query = input("Enter your query (enter $exit to leave) :")
    while query != "$exit":
        collection.BM25(query)
        query = input("Enter your query (enter exit to leave) :")



from setuptools import setup
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

VERSION = '0.3.2'
DESCRIPTION = 'A simple information retrieval system for pdf documents'


setup(
    name='irspdf',
    version=VERSION,
    author='Jibril Frej',
    author_email="<frejjibril@gmail.com>",
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=['irspdf'],
    install_requires=['numpy', 'pdfplumber', 'stop_words', 'snowballstemmer'],
    keywords=['python', 'information retrieval'],
    classifiers=[
        'Programming Language :: Python :: 3'
        ]
)
